Bitcoin Core v32.0

Build and Publish Docker Images
Last commit
Image size

  • Version: v32.0
  • Tag: v32.0
  • Release Date: 2026-10-21
  • Docker Pull Command:
    • docker pull ghcr.io/mocacinno/mocacinno/bitcoin_core_docker:v32.0
    • docker pull mocacinno/btc_core:v32.0
  • Compiled by: Mocacinno
  • Changelog: View Changelog

comments about the image

  • nothing special

flags and parameters

starting the daemon

bash-4.4$ bitcoind -?

       Whether an XOR-key applies to blocksdir *.dat files. The created XOR-key
       will be zeros for an existing blocksdir or when `-blocksxor=0` is
       set, and random for a freshly initialized blocksdir. (default: 1)

  -coinstatsindex
       Maintain coinstats index used by the gettxoutsetinfo RPC (default: 0)

  -conf=<file>
       Specify path to read-only configuration file. Relative paths will be
       prefixed by datadir location (only useable from command line, not
       configuration file) (default: bitcoin.conf)

  -daemon
       Run in the background as a daemon and accept commands (default: 0)

  -daemonwait
       Wait for initialization to be finished before exiting. This implies
       -daemon (default: 0)

  -datadir=<dir>
       Specify data directory

  -dbcache=<n>
       Maximum database cache size <n> MiB (minimum 4, default: 1024). Make
       sure you have enough RAM. In addition, unused memory allocated to
       the mempool is shared with this cache (see -maxmempool).

  -debuglogfile=<file>
       Specify location of debug log file (default: debug.log). Relative paths
       will be prefixed by a net-specific datadir location. Pass
       -nodebuglogfile to disable writing the log to a file.

  -help
       Print this help message and exit (also -h or -?)

  -includeconf=<file>
       Specify additional configuration file, relative to the -datadir path
       (only useable from configuration file, not command line)

  -loadblock=<file>
       Imports blocks from an external file on startup. Obfuscated blocks are
       not supported.

  -maxmempool=<n>
       Keep the transaction memory pool below <n> megabytes (default: 300)

  -mempoolexpiry=<n>

       disk. If an assumeutxo snapshot was loaded, its chainstate will
       be wiped as well. The snapshot can then be reloaded via RPC.

  -settings=<file>
       Specify path to dynamic settings data file. Can be disabled with
       -nosettings. File is written at runtime and not meant to be
       edited by users (use bitcoin.conf instead for custom settings).
       Relative paths will be prefixed by datadir location. (default:
       settings.json)

  -shutdownnotify=<cmd>
       Execute command immediately before beginning shutdown. The need for
       shutdown may be urgent, so be careful not to delay it long (if
       the command doesn't require interaction with the server, consider
       having it fork into the background).

  -startupnotify=<cmd>
       Execute command on startup.

  -txindex
       Maintain a full transaction index, used by the getrawtransaction rpc
       call (default: 0)

  -txospenderindex
       Maintain a transaction output spender index, used by the
       gettxspendingprevout rpc call (default: 0)

  -version
       Print version and exit

Connection options:

  -addnode=<ip>
       Add a node to connect to and attempt to keep the connection open (see
       the addnode RPC help for more info). This option can be specified
       multiple times to add multiple nodes; connections are limited to
       8 at a time and are counted separately from the -maxconnections
       limit.

  -asmap=<file>
       Specify asn mapping used for bucketing of the peers. Relative paths will
       be prefixed by the net-specific datadir location. If a bool arg
       is given (-asmap or -asmap=1), the embedded mapping data in the
       binary will be used.

  -bantime=<n>
       Default duration (in seconds) of manually configured bans (default:


  -listenonion
       Automatically create Tor onion service (default: 1)

  -maxconnections=<n>
       Maintain at most <n> automatic connections to peers (default: 200). 11
       slots of these are reserved for outgoing connections. See
       -inboundrelaypercent for more information about limits applied to
       transaction relay inbound peers. This limit does not apply to
       connections manually added via -addnode or the addnode RPC, which
       have a separate limit of 8. It does not apply to short-lived
       private broadcast connections either, which have a separate limit
       of 64.

  -maxreceivebuffer=<n>
       Maximum per-connection receive buffer, <n>*1000 bytes (default: 5000)

  -maxsendbuffer=<n>
       Maximum per-connection memory usage for the send buffer, <n>*1000 bytes
       (default: 1000)

  -maxuploadtarget=<n>
       Tries to keep outbound traffic under the given target per 24h. Limit
       does not apply to peers with 'download' permission or blocks
       created within past week. 0 = no limit (default: 0M). Optional
       suffix units [k|K|m|M|g|G|t|T] (default: M). Lowercase is 1000
       base while uppercase is 1024 base

  -natpmp
       Use PCP or NAT-PMP to map the listening port (default: 1)

  -networkactive
       Enable all P2P network activity (default: 1). Can be changed by the
       setnetworkactive RPC command

  -onion=<ip:port|path>
       Use separate SOCKS5 proxy to reach peers via Tor onion services, set
       -noonion to disable (default: -proxy). May be a local file path
       prefixed with 'unix:'.

  -onlynet=<net>
       Make automatic outbound connections only to network <net> (ipv4, ipv6,
       onion, i2p, cjdns). Inbound and manual connections are not
       affected by this option. It can be specified multiple times to
       allow multiple networks.

  -peerblockfilters
       Serve compact block filters to peers pe
       Support v2 transport (default: 1)

  -whitebind=<[permissions@]addr>
       Bind to the given address and add permission flags to the peers
       connecting to it. Use [host]:port notation for IPv6. Allowed
       permissions: bloomfilter (allow requesting BIP37 filtered blocks
       and transactions), noban (do not ban for misbehavior; implies
       download), forcerelay (relay transactions that are already in the
       mempool; implies relay), relay (relay even in -blocksonly mode,
       and unlimited transaction announcements), mempool (allow
       requesting BIP35 mempool contents), download (allow getheaders
       during IBD, no disconnect after maxuploadtarget limit), addr
       (responses to GETADDR avoid hitting the cache and contain random
       records with the most up-to-date info). Specify multiple
       permissions separated by commas (default:
       download,noban,mempool,relay). Can be specified multiple times.

  -whitelist=<[permissions@]IP address or network>
       Add permission flags to the peers using the given IP address (e.g.
       1.2.3.4) or CIDR-notated network (e.g. 1.2.3.0/24). Uses the same
       permissions as -whitebind. Additional flags "in" and "out"
       control whether permissions apply to incoming connections and/or
       manual (default: incoming only). Can be specified multiple times.

Wallet options:

  -addresstype
       What type of addresses to use ("legacy", "p2sh-segwit", "bech32",
       "bech32m", default: "bech32")

  -avoidpartialspends
       Group outputs by address, selecting many (possibly all) or none, instead
       of selecting on a per-output basis. Privacy is improved as
       addresses are mostly swept with fewer transactions and outputs
       are aggregated in clean change addresses. It may result in higher
       fees due to less optimal coin selection caused by this added
       limitation and possibly a larger-than-necessary number of inputs
       being used. Always enabled for wallets with "avoid_reuse"
       enabled, otherwise default: 0.

  -changetype
       What type of change to use ("legacy", "p2sh-segwit", "bech32",
       "bech32m"). Default is "legacy" when -addresstype=legacy, else it
       is an implementation detail.

  -consolidatefeerate=<amt>
       The maximum feerate (in BTC/kvB) at which transaction building may use
       more inputs than strictly neces
       if the transaction is not included) and %h is replaced by the
       block height (-1 if not included). %w is not currently
       implemented on windows. On systems where %w is supported, it
       should NOT be quoted because this would break shell escaping used
       to invoke the command.

  -walletrbf
       (DEPRECATED) Send transactions with full-RBF opt-in enabled (default: 1)

ZeroMQ notification options:

  -zmqpubhashblock=<address>
       Enable publish hash block in <address>

  -zmqpubhashblockhwm=<n>
       Set publish hash block outbound message high water mark (default: 1000)

  -zmqpubhashtx=<address>
       Enable publish hash transaction in <address>

  -zmqpubhashtxhwm=<n>
       Set publish hash transaction outbound message high water mark (default:
       1000)

  -zmqpubrawblock=<address>
       Enable publish raw block in <address>

  -zmqpubrawblockhwm=<n>
       Set publish raw block outbound message high water mark (default: 1000)

  -zmqpubrawtx=<address>
       Enable publish raw transaction in <address>

  -zmqpubrawtxhwm=<n>
       Set publish raw transaction outbound message high water mark (default:
       1000)

  -zmqpubsequence=<address>
       Enable publish hash block and tx sequence in <address>

  -zmqpubsequencehwm=<n>
       Set publish hash sequence message high water mark (default: 1000)

Debugging/Testing options:

  -debug=<category>
       Output debug and trace logging (default: -nodebug, supplying <category>
       is optional).
  -signet
       Use the signet chain. Equivalent to -chain=signet. Note that the network
       is defined by the -signetchallenge parameter

  -signetchallenge
       Blocks must satisfy the given script to be considered valid (only for
       signet networks; defaults to the global default signet test
       network challenge)

  -signetseednode
       Specify a seed node for the signet network, in the hostname[:port]
       format, e.g. sig.net:1234 (may be used multiple times to specify
       multiple seed nodes; defaults to the global default signet test
       network seed node(s))

  -testnet
       Use the testnet3 chain. Equivalent to -chain=test. Support for testnet3
       is deprecated and will be removed in an upcoming release.
       Consider moving to testnet4 now by using -testnet4.

  -testnet4
       Use the testnet4 chain. Equivalent to -chain=testnet4.

Node relay options:

  -bytespersigop
       Equivalent bytes per sigop in transactions for relay and mining
       (default: 20)

  -datacarrier
       Relay and mine data carrier transactions (default: 1)

  -datacarriersize
       Relay and mine transactions whose data-carrying raw scriptPubKeys in
       aggregate are of this size or less, allowing multiple outputs
       (default: 100000)

  -minrelaytxfee=<amt>
       Fees (in BTC/kvB) smaller than this are considered zero fee for
       relaying, mining and transaction creation (default: 0.000001)

  -permitbaremultisig
       Relay transactions creating non-P2SH multisig outputs (default: 1)

  -privatebroadcast
       EXPERIMENTAL: Broadcast transactions submitted via sendrawtransaction
       RPC using short-lived connections through the Tor or I2P
       networks, without putting them in the mempool f
       This option is ignored unless -rpcallowip is also passed. Port is
       optional and overrides -rpcport. Use [host]:port notation for
       IPv6. This option can be specified multiple times (default:
       127.0.0.1 and ::1 i.e., localhost)

  -rpccookiefile=<loc>
       Location of the auth cookie. Relative paths will be prefixed by a
       net-specific datadir location. (default: data dir)

  -rpccookieperms=<readable-by>
       Set permissions on the RPC auth cookie file so that it is readable by
       [owner|group|all] (default: owner [via umask 0077])

  -rpcmaxconnections=<n>
       The maximum number of connected HTTP clients (default: 16)

  -rpcpassword=<pw>
       Password for JSON-RPC connections

  -rpcport=<port>
       Listen for JSON-RPC connections on <port> (default: 8332, testnet3:
       18332, testnet4: 48332, signet: 38332, regtest: 18443)

  -rpcthreads=<n>
       Set the number of threads to service RPC calls (default: 16)

  -rpcuser=<user>
       Username for JSON-RPC connections

  -rpcwhitelist=<whitelist>
       Set a whitelist to filter incoming RPC calls for a specific user. The
       field <whitelist> comes in the format: <USERNAME>:<rpc 1>,<rpc
       2>,...,<rpc n>. If multiple whitelists are set for a given user,
       they are set-intersected. See -rpcwhitelistdefault documentation
       for information on default whitelist behavior.

  -rpcwhitelistdefault
       Sets default behavior for rpc whitelisting. Unless rpcwhitelistdefault
       is set to 0, if any -rpcwhitelist is set, the rpc server acts as
       if all rpc users are subject to empty-unless-otherwise-specified
       whitelists. If rpcwhitelistdefault is set to 1 and no
       -rpcwhitelist is set, rpc server acts as if all rpc users are
       subject to empty whitelists.

  -server
       Accept command line and JSON-RPC commands

using bitcoind

bash-4.4$ bitcoin-cli help

getnettotals
getnetworkinfo
getnodeaddresses ( count "network" )
getpeerinfo
listbanned
ping
setban "subnet" "command" ( bantime absolute )
setnetworkactive state

== Rawtransactions ==
abortprivatebroadcast "id"
analyzepsbt "psbt"
combinepsbt ["psbt",...]
combinerawtransaction ["hexstring",...]
converttopsbt "hexstring" ( permitsigdata iswitness psbt_version )
createpsbt [{"txid":"hex","vout":n,"sequence":n},...] [{"address":amount,...},{"data":"hex"},...] ( locktime replaceable version psbt_version )
createrawtransaction [{"txid":"hex","vout":n,"sequence":n},...] [{"address":amount,...},{"data":"hex"},...] ( locktime replaceable version )
decodepsbt "psbt"
decoderawtransaction "hexstring" ( iswitness )
decodescript "hexstring"
descriptorprocesspsbt "psbt" ["",{"desc":"str","range":n or [n,n]},...] ( "sighashtype" bip32derivs finalize )
finalizepsbt "psbt" ( extract )
fundrawtransaction "hexstring" ( options iswitness )
getprivatebroadcastinfo
getrawtransaction "txid" ( verbosity "blockhash" )
joinpsbts ["psbt",...]
sendrawtransaction "hexstring" ( maxfeerate maxburnamount )
signrawtransactionwithkey "hexstring" ["privatekey",...] ( [{"txid":"hex","vout":n,"scriptPubKey":"hex","redeemScript":"hex","witnessScript":"hex","amount":amount},...] "sighashtype" )
submitpackage ["rawtx",...] ( maxfeerate maxburnamount )
testmempoolaccept ["rawtx",...] ( maxfeerate )
utxoupdatepsbt "psbt" ( ["",{"desc":"str","range":n or [n,n]},...] )

== Signer ==
enumeratesigners

== Util ==
createmultisig nrequired ["key",...] ( "address_type" )
deriveaddresses "descriptor" ( range )
estimatesmartfee conf_target ( "estimate_mode" {"fee_rate_estimator":"str","verbosity":n} )
getdescriptorinfo "descriptor"
getindexinfo ( "index_name" )
signmessagewithprivkey "privkey" "message"
validateaddress "address"
verifymessage "address" "signature" "message"

== Wallet ==
abandontransaction "tx
getrawchangeaddress ( "address_type" )
getreceivedbyaddress "address" ( minconf include_immature_coinbase )
getreceivedbylabel "label" ( minconf include_immature_coinbase )
gettransaction "txid" ( include_watchonly verbose )
getwalletinfo
importdescriptors requests
importprunedfunds "rawtransaction" "txoutproof"
keypoolrefill ( newsize )
listaddressgroupings
listdescriptors ( private )
listlabels ( "purpose" )
listlockunspent
listreceivedbyaddress ( minconf include_empty include_watchonly "address_filter" include_immature_coinbase )
listreceivedbylabel ( minconf include_empty include_watchonly include_immature_coinbase )
listsinceblock ( "blockhash" target_confirmations include_watchonly include_removed include_change "label" )
listtransactions ( "label" count skip include_watchonly )
listunspent ( minconf maxconf ["address",...] include_unsafe query_options )
listwalletdir
listwallets
loadwallet "filename" ( load_on_startup )
lockunspent unlock ( [{"txid":"hex","vout":n},...] persistent )
migratewallet ( "wallet_name" "passphrase" load_wallet )
psbtbumpfee "txid" ( options )
removeprunedfunds "txid"
rescanblockchain ( start_height stop_height )
restorewallet "wallet_name" "backup_file" ( load_on_startup )
send [{"address":amount,...},{"data":"hex"},...] ( conf_target "estimate_mode" fee_rate options version )
sendall ["address",{"address":amount,...},...] ( conf_target "estimate_mode" fee_rate options )
sendmany ( "" ) {"address":amount,...} ( minconf "comment" ["address",...] replaceable conf_target "estimate_mode" fee_rate verbose )
sendtoaddress "address" amount ( "comment" "comment_to" subtractfeefromamount replaceable conf_target "estimate_mode" avoid_reuse fee_rate verbose )
setlabel "address" "label"
setwalletflag "flag" ( value )
signmessage "address" "message"
signrawtransactionwithwallet "hexstring" ( [{"txid":"hex","vout":n,"scriptPubKey":"hex","redeemScript":"hex","witnessScript":"hex","amount":amount},...] "sighashtype" )
simulaterawtransaction ["rawtx",...] ( {"include_watchonly":bool,...} )
unloadwallet ( "wallet_name" load_on_startup )
walletcreatefundedpsbt ( [{"txid":"hex","vout":n,"sequence":n,"weight":n},...] ) [{"address":amount,...},{"data":"hex"},...] ( locktime options bip32derivs version psbt_version )
walletdisplayaddress "address"
walletlock
walletpassphrase "passphrase" timeout
walletpassphrasechange "oldpassphrase" "newpassphrase"
walletprocesspsbt "psbt" ( sign "sighashtype" bip32derivs finalize )

== Zmq ==
getzmqnotifications

Previous version: v31.1

Back to the overview

For more information on how to use the Docker image, visit the User Documentation.